@@ -1,10 +1,5 @@
 #!/bin/bash -e
 
-if [ "$JOB" == "3.9-dev" ]; then
-    /bin/bash ci/build39.sh
-    exit 0
-fi
-
 # edit the locale file if needed
 if [[ "$(uname)" == "Linux" && -n "$LC_ALL" ]]; then
     echo "Adding locale to the first line of pandas/__init__.py"
@@ -116,6 +111,12 @@ fi
 echo "activate pandas-dev"
 source activate pandas-dev
 
+# Explicitly set an environment variable indicating that this is pandas' CI environment.
+#
+# This allows us to enable things like -Werror that shouldn't be activated in
+# downstream CI jobs that may also build pandas from source.
+export PANDAS_CI=1
+
 echo
 echo "remove any installed pandas package"
 echo "w/o removing anything else"
